# Table of Contents

- [for-enterprise-architects](<./for-enterprise-architects.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP LeanIX for Enterprise Architects](<./SAP-LeanIX-for-Enterprise-Architects.md>)
  - [Access Your Workspace](<./SAP-LeanIX-for-Enterprise-Architects/Access-Your-Workspace.md>)
  - [Understand the Meta Model](<./SAP-LeanIX-for-Enterprise-Architects/Understand-the-Meta-Model.md>)
  - [Explore Use Cases](<./SAP-LeanIX-for-Enterprise-Architects/Explore-Use-Cases.md>)
  - [Import Data into Your Workspace](<./SAP-LeanIX-for-Enterprise-Architects/Import-Data-into-Your-Workspace.md>)
  - [Collect Data from Fact Sheet Owners](<./SAP-LeanIX-for-Enterprise-Architects/Collect-Data-from-Fact-Sheet-Owners.md>)
